@@ -1,12 +1,9 @@
 import sys
-import io
 import subprocess
 from .colors import RESET
 from .colors import GREEN
 from .colors import RED
 from .colors import BOLD
-from django.test.utils import get_runner
-from django.conf import settings
 
 
 def print_default(text=''):
@@ -46,23 +43,9 @@ def shell_run(cmd):
     return lines
 
 
-def run_unit_tests(apps):
-    old_stderr = sys.stderr
-    old_stdout = sys.stdout
-    new_stdout = io.StringIO()
-    sys.stdout = new_stdout
-    sys.stderr = new_stdout
-
-    TestRunner = get_runner(settings)
-    test_runner = TestRunner(keepdb=True)
-    failures = test_runner.run_tests(apps)
-
-    output = new_stdout.getvalue()
-
-    sys.stderr = old_stderr
-    sys.stdout = old_stdout
-
-    return {
-        "failures": failures,
-        "output": output
-    }
+def run_unit_tests(directory):
+    p = subprocess.Popen(['python3', f'{directory}/manage.py', 'test', '--keepdb'], stdout=subprocess.PIPE,
+                         stderr=subprocess.PIPE)  # nosec
+    q = p.communicate()
+    output = '\n'.join(x.decode('utf-8') for x in q)
+    return output
